@@ -399,7 +399,7 @@ class GitConfiguration(SetupTask):
 
     def run_task(self):
         (Path.home() / ".gitconfig").touch()
-        for key, val in git_settings.items():
+        for key, val in self.get_expected_git_config.items():
             run(f'git config --global --replace-all {key} {val}', shell=True, check=True)
 
     def read_git_config(self, setting):
