@@ -9,6 +9,8 @@ from making_with_code_cli.styles import (
     confirm,
 )
 
+COMMIT_TEMPLATE = ".commit_template"
+
 class GithubBackend(GitBackend):
     """A Github backend. Students own their own repos and grant teachers access via token.
     Note that this gives the teacher account access to the student's entire github account, 
@@ -38,6 +40,9 @@ class GithubBackend(GitBackend):
         cmd = f'gh repo clone "{url}" "{modpath.name}"'
         with cd(modpath.parent):
             run(cmd, shell=True, check=True)
+        if (modpath / COMMIT_TEMPLATE).exists():
+            with cd(modpath):
+                run(f"git config commit.template {COMMIT_TEMPLATE}")
 
     def init_create_from_template(self, module, modpath):
         """Creates the named repo from a template, or clones an existing repo with. 
@@ -50,9 +55,13 @@ class GithubBackend(GitBackend):
         else:
             if modpath.exists():
                 self.relocate_existing_directory(modpath)
-            cmd = f'gh repo create "{modpath.name}" --clone --private --remote {repo_name} --template "{url}"'
+            cmd = f'gh repo create {repo_name} --clone --private --template "{url}"'
         with cd(modpath.parent):
             run(cmd, shell=True, check=True)
+            run(f"mv {repo_name} {modpath.name}", shell=True, check=True) 
+        if (modpath / COMMIT_TEMPLATE).exists():
+            with cd(modpath):
+                run(f"git config commit.template {COMMIT_TEMPLATE}")
 
     def get_repo_name_from_template_repo_url(self, url):
         """Parses the template repo URL and returns the name of a repo to create.
